@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-09-25'; # DATE
-our $VERSION = '1.60'; # VERSION
+our $DATE = '2016-09-28'; # DATE
+our $VERSION = '1.61'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1250,7 +1250,8 @@ sub display_result {
                 require JSON;
                 state $json = JSON->new->allow_nonref;
                 while (defined(my $rec = $x->())) {
-                    print $json->encode($rec), "\n";
+                    print $json->encode(
+                        $self->cleanser->clone_and_clean($rec)), "\n";
                 }
             }
         } else {
@@ -1443,7 +1444,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.60 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-09-25.
+This document describes version 1.61 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-09-28.
 
 =head1 DESCRIPTION
 
